==> handbrake-1.1.1.tar.bz2: HandBrake-1.1.1/win/CS/HandBrakeWPF/Constants.cs <==
﻿// --------------------------------------------------------------------------------------------------------------------
// <copyright file="Constants.cs" company="HandBrake Project (http://handbrake.fr)">
//   This file is part of the HandBrake source code - It may be used under the terms of the GNU General Public License.
// </copyright>
// <summary>
//   Application Constants
// </summary>
// --------------------------------------------------------------------------------------------------------------------

namespace HandBrakeWPF
{
    /// <summary>
    /// Application Constants
    /// </summary>
    public class Constants
    {
        /// <summary>
        /// The appcast 64.
        /// </summary>
        public const string Appcast64 = "https://handbrake.fr/appcast.x86_64.xml";

        /// <summary>
        /// The appcast 32.
        /// </summary>
        public const string Appcast32 = "https://handbrake.fr/appcast.i386.xml";

        /// <summary>
        /// The appcast 32.
        /// </summary>
        public const string AppcastUnstable32 = "https://handbrake.fr/appcast_unstable.i386.xml";

        /// <summary>
        /// The appcast 32.
        /// </summary>
        public const string AppcastUnstable64 = "https://handbrake.fr/appcast_unstable.x86_64.xml";

        /// <summary>
        /// The any.
        /// </summary>
        public const string Any = "(Any)";

        /// <summary>
        /// Undefined Language
        /// </summary>
        public const string Undefined = "und";

        /// <summary>
        /// The chapters.
        /// </summary>
        public const string Chapters = "{chapters}";

        /// <summary>
        /// The title.
        /// </summary>
        public const string Title = "{title}";

        /// <summary>
        /// The quality.
        /// </summary>
        public const string Quality = "{quality}";

        /// <summary>
        /// The quality.
        /// </summary>
        public const string Date = "{date}";

        /// <summary>
        /// The quality.
        /// </summary>
        public const string Time = "{time}";

        /// <summary>
        /// The bitrate.
        /// </summary>
        public const string Bitrate = "{bitrate}";

        /// <summary>
        /// The preset.
        /// </summary>
        public const string Preset = "{preset}";

        /// <summary>
        /// Preset Major Version
        /// </summary>
        public const string PresetVersionMajor = "11";

        /// <summary>
        /// Preset Minor Version
        /// </summary>
        public const string PresetVersionMinor = "0";

        /// <summary>
        /// Preset Micro Version
        /// </summary>
        public const string PresetVersionMicro = "0";
    }
}

==> handbrake-1.4.2.tar.bz2: HandBrake-1.4.2/win/CS/HandBrakeWPF/Constants.cs <==
﻿// --------------------------------------------------------------------------------------------------------------------
// <copyright file="Constants.cs" company="HandBrake Project (http://handbrake.fr)">
//   This file is part of the HandBrake source code - It may be used under the terms of the GNU General Public License.
// </copyright>
// <summary>
//   Application Constants
// </summary>
// --------------------------------------------------------------------------------------------------------------------

namespace HandBrakeWPF
{
    /// <summary>
    /// Application Constants
    /// </summary>
    public class Constants
    {
        /* Appcast URLs */
        public const string Appcast64 = "https://handbrake.fr/appcast.x86_64.xml";
        public const string AppcastUnstable64 = "https://handbrake.fr/appcast_unstable.x86_64.xml";

        public const string Appcast64Arm = "https://handbrake.fr/appcast.arm64.xml";
        public const string AppcastUnstable64Arm = "https://handbrake.fr/appcast_unstable.arm64.xml";

        /* Languages */
        public const string Any = "(Any)";
        public const string Undefined = "und";

        /* Auto-name Constants */
        public const string Chapters = "{chapters}";
        public const string Title = "{title}";
        public const string Quality = "{quality}";
        public const string Date = "{date}";
        public const string Time = "{time}";
        public const string CreationDate = "{creation-date}";
        public const string CreationTime = "{creation-time}";
        public const string Bitrate = "{bitrate}";
        public const string Preset = "{preset}";

        /* Auto-name Path Constants */
        public const string Source = "{source}";
        public const string SourcePath = "{source_path}";
        public const string SourceFolderName = "{source_folder_name}";

        public const string FileScanMru = "FileScanMru";
        public const string FileSaveMru = "FileSaveMru";
    }
}
